@@ -36,9 +36,9 @@ package Pgreet::Error;
 # handling.  It defines common conditions that are then handled
 # differently by the CGI application and the system daemon.
 ######################################################################
-# $Id: Error.pm,v 1.11 2003/08/31 02:31:19 elagache Exp $
+# $Id: Error.pm,v 1.15 2003/09/26 20:52:43 elagache Exp $
 
-$VERSION = "0.9.1"; # update after release
+$VERSION = "0.9.2"; # update after release
 
 # Module exporter declarations
 @ISA       = qw(Exporter);
@@ -60,8 +60,7 @@ use strict;
 
 sub new {
 #
-# Traditional empty contructor.  Any
-# real work will be done by '_init'
+# Create new object and make required assignments.
 #
   my $class = shift;
   my $Pg_config = shift;
@@ -89,21 +88,33 @@ sub new {
   elsif ($AppType =~ m/App/i) {
 	$self->{'AppType'} = 'App';
   } else {
+	# Should never reach this statement.
 	die "Unknown application type trying to create Pgreet Error object";
   }
 
   return($self);
 }
 
+sub add_cgi_obj {
+#
+# Method to attach a Penguin Greetings CGIUtils object to
+# Error object so that the variables transferred to Embperl
+# are the same for a call from the main CGI application as
+# there are from an error condition.
+#
+  my $self = shift;
+  my $Pg_cgi = shift;
 
+  return($self->{'Pg_cgi'} = $Pg_cgi);
+
+}
 
 sub report {
 #
 # Main error reporting method.  If running as CGI report,
-# output via warn and die.  Else report the errors via
-# the Log::Dispatch object.  To simplify matters, only
-# error or higher are reported to syslog.  All else are
-# sent to pgreet.log only.
+# output via warn and die.  If a daemon, report the errors
+# via the Log::Dispatch object.  Else report errors via
+# traditional STDERR.
 #
   my $self = shift;
   my $level = shift;
@@ -123,7 +134,7 @@ sub report_cgi {
 #
 # Main error reporting method for CGI application.  If
 # this is a "serious" error, report via 'die', else
-# report via 'warn.'  Of course actually croak/carp
+# report via 'warn.'  Of course actually croak/carp.
 # If first item is just a number, it is taken as an
 # error number and sent out as a error_template
 # request.
@@ -150,8 +161,9 @@ sub report_daemon {
 # Main error reporting for the system daemon which
 # reports the errors via the Log::Dispatch object.
 # To simplify matters, only error or higher are
-# reported to syslog.  All else are
-# sent to pgreet.log only.
+# reported to syslog.  All else are sent to pgreet.log
+# only.  If call is error or higher, then application
+# is halted here with an exit(1) call.
 #
   my $self = shift;
   my $level = shift;
@@ -174,6 +186,7 @@ sub report_daemon {
     $syslog_obj->log(level => $level,
 					 message => join('', @messages)
 					);
+	exit(1);
   }
 
 }
@@ -213,6 +226,30 @@ sub _is_error {
 		 );
 }
 
+sub _LocalChangeVars {
+#
+# "Cheater" subroutine that allows Error.pm to deal with CGI
+# errors even if the CGIUtils object isn't defined when called
+#
+  my $self = shift;
+  my $error_no = shift;
+  my $Pg_config = $self->{'Pg_config'};
+
+  my $file = $Pg_config->access('default_error');
+  my $templatedir = $Pg_config->access('templatedir');
+  my $imageurl = $Pg_config->access('imageurl');
+  my $hostname = $Pg_config->access('hostname');
+
+  # Create tiny Transfer hash.
+  my $Transfer = { hostname => $hostname,
+				   templatedir => $templatedir,
+				   error_no => $error_no,
+				   imageurl => $imageurl,
+				 };
+
+  return($Transfer);
+}
+
 sub error_template {
 #
 # Method to send an error message to the CGI server via
@@ -224,17 +261,18 @@ sub error_template {
 
   my $file = $Pg_config->access('default_error');
   my $templatedir = $Pg_config->access('templatedir');
-  my $imageurl = $Pg_config->access('imageurl');
   my $tpl = $Pg_config->access('template_suffix');
+  my $Transfer;
+  my $Pg_cgi;
 
-  # Get Transfer hash
-#  my $Transfer = ChangeVars();
-  # XXXX once more temporary until CGIUtils can be finished.
-  my $Transfer = { hostname => 'www.canebas.org',
-				   templatedir => $templatedir,
-				   error_no => $error_no,
-				   imageurl => $imageurl,
-				 };
+  # If CGIUtils object defined, used that for variables.
+  if (exists($self->{'Pg_cgi'})) {
+	$Pg_cgi = $self->{'Pg_cgi'};
+	$Pg_cgi->set_value('error_no', $error_no);
+	$Transfer = $Pg_cgi->ChangeVars();
+  } else { # Else use "cheater" local stub routine.
+	$Transfer = $self->_LocalChangeVars($error_no);
+  }
 
   print "Content-type: text/html\n\n";
   Embperl::Execute ({inputfile  => "$templatedir/$file.$tpl",
@@ -254,6 +292,10 @@ Pgreet::Error - Error handling object for Penguin Greetings.
   # Constructor:
   $Pg_error = new Pgreet::Error($Pg_default_config, 'CGIApp');
 
+  # Attach new CGIUtils object to Error obj.
+  $Pg_error->add_cgi_obj($Pg_cgi);
+
+
   # Error reporting:
   $Pg_error->report('level',
                     "any number of diagnostic message",
@@ -263,7 +305,7 @@ Pgreet::Error - Error handling object for Penguin Greetings.
 =head1 DESCRIPTION
 
 The module C<Pgreet::Error> is the Penguin Greetings
-content-independent error handling module.  This module uses the same
+context-independent error handling module.  This module uses the same
 syntax whether being called from a "faceless" daemon, a CGI
 application, or a command line utility.  More importantly, library
 routines calling the error object passed as a parameter can correctly
@@ -301,16 +343,25 @@ From that point on, this error object can be used to report errors in
 the application that created it and passed on to other modules so that
 errors occurring in those modules will be handled consistently.
 
+New to version 0.9.2 is a method to attach a C<Pgreet::CGIUtils>
+object to the error object.  The method to do this is simply:
+C<add_cgi_obj>, and takes a single argument, a reference to the
+C<Pgreet::CGIUtils> object.  A sample call is provided below:
+
+  # Attach new CGIUtils object to Error obj.
+  $Pg_error->add_cgi_obj($Pg_cgi);
+
 =head1 ERROR REPORTING SYNTAX
 
-There is only one method that developers should ever use from this
-module - it is the C<report> method.  The report method takes a error
-level (from syslog) and any number of Perl expressions and outputs a
-string in the appropriate venue.  If the error is severe enough,
-C<report> will cause the program to halt in a manner appropriate to
-the way the program is called.  If called from a CGI application,
-report can output an HTML template with an error message based on a
-supplied error number.  A sample call to C<report> is below:
+Once the object is set up, there is only one method that developers
+should ever use from this module - it is the C<report> method.  The
+report method takes a error level (from syslog) and any number of Perl
+expressions and outputs a string in the appropriate venue.  If the
+error is severe enough, C<report> will cause the program to halt in a
+manner appropriate to the way the program is called.  If called from a
+CGI application, report can output an HTML template with an error
+message based on a supplied error number.  A sample call to C<report>
+is below:
 
   # Error reporting:
   $Pg_error->report('level',
@@ -382,6 +433,15 @@ following error levels: 'error', 'critical', 'alert', or 'emergency'
 method to send an error message out via the content developers
 L<Embperl> template.
 
+=item _LocalChangeVars()
+
+A "stub" routine to replace the C<Pgreet::CGIUtils> C<ChangeVars>
+method if C<report> is called before the C<Pgreet::CGIUtils> object
+has been attached to the report object.  It is sufficient for the
+extreme cases when such a call might be made, but should basically be
+never used if the software if functioning correctly and configuration
+files are "reasonable."
+
 =back
 
 =head1 COPYRIGHT
@@ -402,7 +462,7 @@ Edouard Lagache <pgreetdev@canebas.org>
 
 =head1 VERSION
 
-0.9.1
+0.9.2
 
 =head1 SEE ALSO
 
